package org.parallelj.launching.reflect;

import java.beans.IntrospectionException;
import java.beans.Introspector;
import java.beans.PropertyDescriptor;
import java.lang.reflect.Field;
import java.lang.reflect.Method;
import java.util.ArrayList;
import java.util.List;

import org.parallelj.internal.reflect.AnnotationBasedBuilderFactory;
import org.parallelj.internal.reflect.ElementBuilder;
import org.parallelj.launching.ReturnCode;
import org.parallelj.launching.LaunchingMessageKind;
import org.parallelj.launching.usercode.IUserReturnCode;

public class UserReturnCodeBuilderFactory extends AnnotationBasedBuilderFactory {

	public static class UserReturnCodeBuilder extends AnnotationBasedBuilder<ReturnCode, Field> {
		@Override
		public ElementBuilder complete() {
			// Get all the informations about the field annotated with @ErrorCode
			String fieldName = this.getMember().getName();
			Method getReadFieldMethod = null;
			// Get the setter method for the Field
			Class<?> programType = this.getBuilder().getType();
			try {
				for (PropertyDescriptor descriptor : Introspector.getBeanInfo(programType)
						.getPropertyDescriptors()) {
					if (descriptor.getName().equals(fieldName)) {
						getReadFieldMethod = descriptor.getReadMethod();
						 break;
					}
				}
			} catch (IntrospectionException e) {
				LaunchingMessageKind.ELAUNCH0006.format(programType, fieldName, e);
			}
			if (getReadFieldMethod==null) {
				LaunchingMessageKind.ELAUNCH0006.format(programType, fieldName, new Exception());
			}

			// Add the argument to the KProgram
			((IUserReturnCode)this.getProgram()).setUserReturnCodeGetterMethod(getReadFieldMethod);
			return super.complete();
		}
	}

	public UserReturnCodeBuilderFactory(
			List<Class<? extends AnnotationBasedBuilder<?, ?>>> types) {
		super(types);
	}

	static final List<Class<? extends AnnotationBasedBuilder<?, ?>>> types = new ArrayList<Class<? extends AnnotationBasedBuilder<?, ?>>>();

	static {
		types.add(UserReturnCodeBuilder.class);
	}

	public UserReturnCodeBuilderFactory() {
		super(types);
	}


}
